@@ -22,12 +22,13 @@ use std::{
     borrow::{Borrow, Cow},
     convert::Infallible,
     ffi::OsStr,
-    fmt::{self, Error as FmtError, Write as FmtWrite},
+    fmt::{self, Write as FmtWrite},
     iter::FromIterator,
     path::Path,
     str::FromStr,
     string::FromUtf8Error,
 };
+pub use smartstring::MAX_INLINE;
 
 #[cfg(feature = "diesel_types")]
 use diesel::{
@@ -97,10 +98,14 @@ impl StackString {
         }
     }
 
-    pub fn from_display(buf: impl fmt::Display) -> Result<Self, FmtError> {
+    /// # Panics
+    /// from_display panics if a formatting trait implementation returns an
+    /// error. This indicates an incorrect implementation
+    /// since `fmt::Write for String` never returns an error itself.
+    pub fn from_display(buf: impl fmt::Display) -> Self {
         let mut s = Self::new();
-        write!(s, "{}", buf)?;
-        Ok(s)
+        write!(s, "{}", buf).unwrap();
+        s
     }
 }
 
@@ -346,6 +351,15 @@ impl sqlx_core::decode::Decode<'_, sqlx_core::postgres::Postgres> for StackStrin
     }
 }
 
+#[macro_export]
+macro_rules! format_sstr {
+    ($($arg:tt)*) => {{
+        let mut buf = $crate::StackString::new();
+        std::write!(buf, "{}", std::format_args!($($arg)*)).unwrap();
+        buf
+    }}
+}
+
 #[cfg(test)]
 mod tests {
     use rand::{thread_rng, Rng};
@@ -507,4 +521,30 @@ mod tests {
         }
         assert_eq!(buf.as_ref(), b"Hello There");
     }
+
+    #[test]
+    fn test_from_display() {
+        use std::fmt::Display;
+
+        struct Test {}
+
+        impl Display for Test {
+            fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+                f.write_str("THIS IS A TEST")
+            }
+        }
+
+        let t = Test {};
+        let s = StackString::from_display(t);
+        assert_eq!(s, StackString::from("THIS IS A TEST"));
+    }
+
+    #[test]
+    fn test_format_sstr() {
+        use crate::format_sstr;
+        use std::fmt::Write;
+
+        let s = format_sstr!("This is a test {}", 22);
+        assert_eq!(s, StackString::from("This is a test 22"));
+    }
 }
